<?php
/*
Plugin Name: Visitor Info Table
Description: Displays visitor information in a table format using a shortcode [visitor_info]. Plugin also shows total number of visitors.
Version: 1.1
Author: Jarno Jaskari
*/

// Activation tasks
function visitor_info_activate() {
    global $wpdb;

    // Create a table in the database if it doesn't already exist
    $table_name = $wpdb->prefix . 'visitor_info';
    if ($wpdb->get_var("SHOW TABLES LIKE '$table_name'") != $table_name) {
        $charset_collate = $wpdb->get_charset_collate();
        $sql = "CREATE TABLE $table_name (
            id mediumint(9) NOT NULL AUTO_INCREMENT,
            visit_date datetime DEFAULT CURRENT_TIMESTAMP NOT NULL,
            ip_address varchar(100) NOT NULL,
            dns_name varchar(255) NOT NULL,
            PRIMARY KEY  (id)
        ) $charset_collate;";
        require_once(ABSPATH . 'wp-admin/includes/upgrade.php');
        dbDelta($sql);
    }
}
register_activation_hook(__FILE__, 'visitor_info_activate');

// Uninstall tasks
function visitor_info_uninstall() {
    global $wpdb;

    // Delete the table created by the plugin
    $table_name = $wpdb->prefix . 'visitor_info';
    $wpdb->query("DROP TABLE IF EXISTS $table_name");
}
register_uninstall_hook(__FILE__, 'visitor_info_uninstall');

// Save visitor information
function log_visitor_info() {
    global $wpdb;

    // Retrieve IP address and DNS name
    $ip_address = $_SERVER['REMOTE_ADDR'];
    $dns_name = gethostbyaddr($ip_address);

    // Insert data into the database
    $table_name = $wpdb->prefix . 'visitor_info';
    $wpdb->insert(
        $table_name,
        array(
            'ip_address' => $ip_address,
            'dns_name'   => $dns_name,
        )
    );
}
add_action('wp_footer', 'log_visitor_info'); // Log information for each visit

// Shortcode to display visitor information in a table
function visitor_info_shortcode() {
    global $wpdb;

    // Retrieve all data from the database
    $table_name = $wpdb->prefix . 'visitor_info';
    $results = $wpdb->get_results("SELECT * FROM $table_name ORDER BY visit_date DESC");

    // If no data exists, return an empty message
    if (empty($results)) {
        return '<p>No visitor information available.</p>';
    }

    // Count total visitors
    $visitor_count = $wpdb->get_var("SELECT COUNT(*) FROM $table_name");

    // Create an HTML table
    $output = "<p><strong>Total Visitors:</strong> $visitor_count</p>";
    $output .= '<table border="1" style="width: 100%; border-collapse: collapse;">';
    $output .= '<thead><tr><th>Date</th><th>Time</th><th>IP Address</th><th>DNS Name</th></tr></thead>';
    $output .= '<tbody>';

    foreach ($results as $row) {
        $date = date('d.m.Y', strtotime($row->visit_date));
        $time = date('H:i:s', strtotime($row->visit_date));
        $output .= "<tr>
                        <td>{$date}</td>
                        <td>{$time}</td>
                        <td>{$row->ip_address}</td>
                        <td>{$row->dns_name}</td>
                    </tr>";
    }

    $output .= '</tbody></table>';

    return $output;
}
add_shortcode('visitor_info', 'visitor_info_shortcode');
?>
